PublicKey class

A class representing a public key

Constructors

PublicKey(GroupElement point, ECDomainParameters params)

Properties

hashCode → int
The hash code for this object.
no setterinherited
params → ECDomainParameters
final
point → GroupElement
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBase64() → String
Convert PublicKey to base64 string
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBase64(String base64, [ECDomainParameters? params]) → PublicKey
Create a PublicKey from base64 string